Learn R Programming

mlr3tuning (version 0.7.0)

ArchiveTuning: Logging object for objective function evaluations

Description

Container around a data.table::data.table() which stores all performed function calls of the Objective and the associated mlr3::BenchmarkResult.

$benchmark_result stores a mlr3::BenchmarkResult which contains the mlr3::ResampleResult of all performed function calls. The mlr3::BenchmarkResult is connected to the data.table::data.table via the uhash column.

Arguments

Super class

bbotk::Archive -> ArchiveTuning

Public fields

benchmark_result

(mlr3::BenchmarkResult) Stores benchmark result.

Active bindings

extended_archive

(data.table::data.table()) Joins each performed function call of the Objective with the corresponding mlr3::ResampleResult.

Methods

Public methods

Method learner()

Retrieve mlr3::Learner of the i-th evaluation, by position or by unique hash uhash. i and uhash are mutually exclusive. Learner does not contain a model. Use $learners() to get learners with models.

Usage

ArchiveTuning$learner(i = NULL, uhash = NULL)

Arguments

i

(integer(1)) The iteration value to filter for.

uhash

(logical(1)) The uhash value to filter for.

Method learners()

Retrieve list of trained mlr3::Learner objects of the i-th evaluation, by position or by unique hash uhash. i and uhash are mutually exclusive.

Usage

ArchiveTuning$learners(i = NULL, uhash = NULL)

Arguments

i

(integer(1)) The iteration value to filter for.

uhash

(logical(1)) The uhash value to filter for.

Method learner_param_vals()

Retrieve param values of the i-th evaluation, by position or by unique hash uhash. i and uhash are mutually exclusive.

Usage

ArchiveTuning$learner_param_vals(i = NULL, uhash = NULL)

Arguments

i

(integer(1)) The iteration value to filter for.

uhash

(logical(1)) The uhash value to filter for.

Method predictions()

Retrieve list of mlr3::Prediction objects of the i-th evaluation, by position or by unique hash uhash. i and uhash are mutually exclusive.

Usage

ArchiveTuning$predictions(i = NULL, uhash = NULL)

Arguments

i

(integer(1)) The iteration value to filter for.

uhash

(logical(1)) The uhash value to filter for.

Method resample_result()

Retrieve mlr3::ResampleResult of the i-th evaluation, by position or by unique hash uhash. i and uhash are mutually exclusive.

Usage

ArchiveTuning$resample_result(i = NULL, uhash = NULL)

Arguments

i

(integer(1)) The iteration value to filter for.

uhash

(logical(1)) The uhash value to filter for.

Method clone()

The objects of this class are cloneable with this method.

Usage

ArchiveTuning$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.