Learn R Programming

mlr3tuning (version 1.6.1)

TuningInstanceMultiCrit: Multi Criteria Tuning Instance for Batch Tuning

Description

TuningInstanceMultiCrit is a deprecated class that is now a wrapper around TuningInstanceBatchMultiCrit.

Arguments

Super classes

bbotk::EvalInstance -> bbotk::OptimInstance -> bbotk::OptimInstanceBatch -> bbotk::OptimInstanceBatchMultiCrit -> TuningInstanceBatchMultiCrit -> TuningInstanceMultiCrit

Methods

Inherited methods

TuningInstanceMultiCrit$new()

Creates a new instance of this R6 class.

Usage

TuningInstanceMultiCrit$new(
  task,
  learner,
  resampling,
  measures,
  terminator,
  search_space = NULL,
  store_benchmark_result = TRUE,
  store_models = FALSE,
  check_values = FALSE,
  callbacks = NULL
)

Arguments

task

(mlr3::Task)
Task to operate on.

learner

(mlr3::Learner)
Learner to tune.

resampling

(mlr3::Resampling)
Resampling that is used to evaluate the performance of the hyperparameter configurations. Uninstantiated resamplings are instantiated during construction so that all configurations are evaluated on the same data splits. Already instantiated resamplings are kept unchanged. Specialized Tuner change the resampling e.g. to evaluate a hyperparameter configuration on different data splits. This field, however, always returns the resampling passed in construction.

measures

(list of mlr3::Measure)
Measures to optimize.

terminator

(bbotk::Terminator)
Stop criterion of the tuning process.

search_space

(paradox::ParamSet)
Hyperparameter search space. If NULL (default), the search space is constructed from the paradox::TuneToken of the learner's parameter set (learner$param_set). When using to_tune() tokens, dependencies for hierarchical search spaces are automatically handled.

store_benchmark_result

(logical(1))
If TRUE (default), store resample result of evaluated hyperparameter configurations in archive as mlr3::BenchmarkResult.

store_models

(logical(1))
If TRUE, fitted models are stored in the benchmark result (archive$benchmark_result). Setting store_models = TRUE implies store_benchmark_result = TRUE, i.e. an explicit store_benchmark_result = FALSE is overridden.

check_values

(logical(1))
If TRUE, hyperparameter values are checked before evaluation and performance scores after. If FALSE (default), values are unchecked but computational overhead is reduced.

callbacks

(list of mlr3misc::Callback)
List of callbacks.


TuningInstanceMultiCrit$clone()

The objects of this class are cloneable with this method.

Usage

TuningInstanceMultiCrit$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.