Subclass for asynchronous design points tuning.
This Tuner can be instantiated with the associated sugar function tnr():
tnr("async_design_points")
designdata.table::data.table
Design points to try in search, one per row.
Tuner -> TunerAsync -> TunerAsyncFromOptimizerAsync -> TunerAsyncDesignPoints
Inherited methods
TunerAsyncDesignPoints$new()Creates a new instance of this R6 class.
TunerAsyncDesignPoints$new()TunerAsyncDesignPoints$clone()The objects of this class are cloneable with this method.
TunerAsyncDesignPoints$clone(deep = FALSE)deepWhether to make a deep clone.
Other TunerAsync:
mlr_tuners_async_grid_search,
mlr_tuners_async_random_search