Subclass for asynchronous grid search tuning.
This Tuner can be instantiated with the associated sugar function tnr():
tnr("async_grid_search")
batch_sizeinteger(1)
Maximum number of points to try in a batch.
Tuner -> TunerAsync -> TunerAsyncFromOptimizerAsync -> TunerAsyncGridSearch
Inherited methods
TunerAsyncGridSearch$new()Creates a new instance of this R6 class.
TunerAsyncGridSearch$new()TunerAsyncGridSearch$clone()The objects of this class are cloneable with this method.
TunerAsyncGridSearch$clone(deep = FALSE)deepWhether to make a deep clone.
Other TunerAsync:
mlr_tuners_async_design_points,
mlr_tuners_async_random_search