Subclass for asynchronous random search tuning.
This Tuner can be instantiated with the associated sugar function tnr():
tnr("async_random_search")
Tuner -> TunerAsync -> TunerAsyncFromOptimizerAsync -> TunerAsyncRandomSearch
Inherited methods
TunerAsyncRandomSearch$new()Creates a new instance of this R6 class.
TunerAsyncRandomSearch$new()TunerAsyncRandomSearch$clone()The objects of this class are cloneable with this method.
TunerAsyncRandomSearch$clone(deep = FALSE)deepWhether to make a deep clone.
The random points are sampled by paradox::generate_design_random().
Other TunerAsync:
mlr_tuners_async_design_points,
mlr_tuners_async_grid_search