| mlr_tuners_cmaes | R Documentation |
Subclass for Covariance Matrix Adaptation Evolution Strategy (CMA-ES).
Calls libcmaesr::cmaes() from package libcmaesr.
This Tuner can be instantiated with the associated sugar function tnr():
tnr("cmaes")
$optimize() supports progress bars via the package progressr
combined with a bbotk::Terminator. Simply wrap the function in
progressr::with_progress() to enable them. We recommend to use package
progress as backend; enable with progressr::handlers("progress").
All Tuners use a logger (as implemented in lgr) from package
bbotk.
Use lgr::get_logger("bbotk") to access and control the logger.
This Tuner is based on bbotk::OptimizerBatchCmaes which can be applied on any black box optimization problem. See also the documentation of bbotk.
start_valuescharacter(1)
Create "random" start values or based on "center" of search space?
In the latter case, it is the center of the parameters before a trafo is applied.
If set to "custom", the start values can be passed via the start parameter.
startnumeric()
Custom start values. Only applicable if start_values parameter is set to "custom".
seedinteger(1)
Seed of the random number generator of libcmaes.
Unset by default, in which case the generator is seeded from R and the optimization is reproducible with
set.seed().
All remaining parameters are passed to libcmaesr::cmaes_control(), see there for their meaning.
Note that we have removed all control parameters which refer to the termination of the algorithm and where our
terminators allow to obtain the same behavior, i.e. max_fevals, max_iter, and ftarget.
The internal convergence criteria of the algorithm still apply, so the optimization can stop before the
Terminator is triggered.
The optimizer evaluates a whole generation of lambda points in one batch.
The Terminator is only checked between generations, so the number of evaluations can exceed the budget of
TerminatorEvals by up to lambda - 1 points.
There are several sections about hyperparameter optimization in the mlr3book.
Getting started with hyperparameter optimization.
An overview of all tuners can be found on our website.
Tune a support vector machine on the Sonar data set.
Learn about tuning spaces.
Estimate the model performance with nested resampling.
Learn about multi-objective optimization.
Simultaneously optimize hyperparameters and use early stopping with XGBoost.
Automate the tuning.
The gallery features a collection of case studies and demos about optimization.
Learn more advanced methods with the Practical Tuning Series.
Learn about hotstarting models.
Run the default hyperparameter configuration of learners as a baseline.
Use the Hyperband optimizer with different budget parameters.
The cheatsheet summarizes the most important functions of mlr3tuning.
Tuner -> TunerBatch -> TunerBatchFromOptimizerBatch -> TunerBatchCmaes
TunerBatchCmaes$new()Creates a new instance of this R6 class.
TunerBatchCmaes$new()
TunerBatchCmaes$clone()The objects of this class are cloneable with this method.
TunerBatchCmaes$clone(deep = FALSE)
deepWhether to make a deep clone.
Hansen N (2016). “The CMA Evolution Strategy: A Tutorial.” 1604.00772.
Other Tuner:
Tuner,
mlr_tuners,
mlr_tuners_design_points,
mlr_tuners_gensa,
mlr_tuners_grid_search,
mlr_tuners_internal,
mlr_tuners_irace,
mlr_tuners_nloptr,
mlr_tuners_random_search
# example only runs if libcmaesr is available
if (mlr3misc::require_namespaces("libcmaesr", quietly = TRUE)) {
# Hyperparameter Optimization
# load learner and set search space
learner = lrn("classif.rpart",
cp = to_tune(1e-04, 1e-1, logscale = TRUE),
minsplit = to_tune(p_dbl(2, 128, trafo = as.integer)),
minbucket = to_tune(p_dbl(1, 64, trafo = as.integer))
)
# run hyperparameter tuning on the Palmer Penguins data set
instance = tune(
tuner = tnr("cmaes"),
task = tsk("penguins"),
learner = learner,
resampling = rsmp("holdout"),
measure = msr("classif.ce"),
term_evals = 10)
# best performing hyperparameter configuration
instance$result
# all evaluated hyperparameter configuration
as.data.table(instance$archive)
# fit final model on complete data set
learner$param_set$values = instance$result_learner_param_vals
learner$train(tsk("penguins"))
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.