- tuner
(Tuner)
Optimization algorithm.
- task
(mlr3::Task)
Task to operate on.
- learner
(mlr3::Learner)
Learner to tune.
- inner_resampling
(mlr3::Resampling)
Resampling used for the inner loop.
- outer_resampling
mlr3::Resampling)
Resampling used for the outer loop.
- measure
(mlr3::Measure)
Measure to optimize. If NULL, default measure is used.
- term_evals
(integer(1))
Number of allowed evaluations.
Ignored if terminator is passed.
- term_time
(integer(1))
Maximum allowed time in seconds.
Ignored if terminator is passed.
- terminator
(bbotk::Terminator)
Stop criterion of the tuning process.
- search_space
(paradox::ParamSet)
Hyperparameter search space.
If NULL (default), the search space is constructed from the paradox::TuneToken of the learner's parameter set (learner$param_set).
When using to_tune() tokens, dependencies for hierarchical search spaces are automatically handled.
- store_tuning_instance
(logical(1))
If TRUE (default), stores the internally created TuningInstanceBatchSingleCrit with all intermediate results in slot $tuning_instance.
Setting store_benchmark_result = TRUE implies store_tuning_instance = TRUE,
i.e. an explicit store_tuning_instance = FALSE is overridden.
- store_benchmark_result
(logical(1))
If TRUE (default), store resample result of evaluated hyperparameter
configurations in archive as mlr3::BenchmarkResult.
- store_models
(logical(1))
If TRUE, fitted models are stored in the benchmark result (archive$benchmark_result).
Setting store_models = TRUE implies store_benchmark_result = TRUE,
i.e. an explicit store_benchmark_result = FALSE is overridden.
- check_values
(logical(1))
If TRUE, hyperparameter values are checked before evaluation and
performance scores after. If FALSE (default), values are unchecked but
computational overhead is reduced.
- callbacks
(list of mlr3misc::Callback)
List of callbacks.